function createBoxes(jsonData) {
    var tree;
    var baseSvg, svgGroup, nodeGroup, nodeGroupTooltip, linkGroup, linkGroupToolTip, defs;
    var width = 850, height = 420;
    var boxNode = { width: 120, height: 45, textMargin: 5 };
    var tooltip = { width: 150, height: 40, textMargin: 5 };
    var i = 0, duration = 600, root;

    if (jsonData)
        drawFamilyTree(jsonData);
    else
        alert('No data Mapped.');

    function drawFamilyTree(jsonData) {
        tree = d3.layout.tree().size([height, width]);
        root = jsonData;
        root.fixed = true;

        var maxDepth = 0;
        var maxTreeWidth = breadthFirstTraversal(tree.nodes(root), function (currentLevel) {
            maxDepth++;
            currentLevel.forEach(function (node) {
                if (node.type == 'type0')
                    node.color = 'lightgreen';
                if (node.type == 'type1')
                    node.color = 'lightgrey';
                if (node.type == 'type2')
                    node.color = 'lightblue';
                if (node.type == 'type3')
                    node.color = 'lightpink';
            });
        });
        height = maxTreeWidth * (boxNode.height + 20) + tooltip.height + 20;
        width = maxDepth * (boxNode.width * 1.5) + tooltip.width / 2;

        tree = d3.layout.tree().size([height, width]);
        root.x0 = height / 2;
        root.y0 = 0;

        baseSvg = d3.select('#tree-container').append('svg')
            .attr('width', width)
            .attr('height', height + 120)
            .attr('class', 'svgContainer');

        svgGroup = baseSvg.append('g')
            .attr('class', 'drawarea')
            .append('g');

        nodeGroup = svgGroup.append('g')
            .attr('id', 'nodes');
        linkGroup = svgGroup.append('g')
            .attr('id', 'links');
        linkGroupToolTip = svgGroup.append('g')
            .attr('id', 'linksTooltips');
        nodeGroupTooltip = svgGroup.append('g')
            .attr('id', 'nodesTooltips');

        defs = baseSvg.append('defs');
        initAddArrows();
        initAddGraphics();

        updateLayout(root);
    }

    function updateLayout(source) {
        var nodes = tree.nodes(root).reverse(),
            links = tree.links(nodes);

        breadthFirstTraversal(tree.nodes(root), collision);

        nodes.forEach(function (d) {
            d.y = d.depth * (boxNode.width * 1.5);
        });

        var node = nodeGroup.selectAll('g.node').data(nodes, function (d) {
            return d.id || (d.id = ++i);
        });
        var nodesTooltip = nodeGroupTooltip.selectAll('g').data(nodes, function (d) {
            return d.id || (d.id = ++i);
        });

        var nodeEnter = node.enter().insert('g', 'g.node')
            .attr('class', 'node')
            .attr('transform', function (d) { return 'translate(' + source.y0 + ',' + source.x0 + ')'; })
            .on('click', function (d) { click(d); });
        var nodeEnterTooltip = nodesTooltip.enter().append('g')
            .attr('transform', function (d) { return 'translate(' + source.y0 + ',' + source.x0 + ')'; });

        nodeEnter.append('rect')
            .attr('rx', 6)
            .attr('ry', 6)
            .attr('width', boxNode.width)
            .attr('height', boxNode.height)
            .attr('class', 'node-rect')
            .attr('fill', function (d) { return d.color; });

        nodeEnter.append('text')
            .attr('x', boxNode.textMargin)
            .attr('y', boxNode.textMargin)
            .attr('dy', '.35em')
            .text(function (d) { return d.name; });

        var nodeUpdate = node.transition().duration(duration)
            .attr('transform', function (d) { return 'translate(' + d.y + ',' + d.x + ')'; });

        var nodeExit = node.exit().transition().duration(duration)
            .attr('transform', function (d) { return 'translate(' + source.y + ',' + source.x + ')'; })
            .remove();

        var link = linkGroup.selectAll('path').data(links, function (d) {
            return d.target.id;
        });

        var linkenter = link.enter().insert('path', 'g')
            .attr('class', 'link')
            .attr('id', function (d) { return 'linkID' + d.target.id; })
            .attr('d', function (d) { return diagonalArrows(d); });

        var linkUpdate = link.transition().duration(duration)
            .attr('d', function (d) { return diagonal(d); });

        nodes.forEach(function (d) {
            d.x0 = d.x;
            d.y0 = d.y;
        });
    }

    function breadthFirstTraversal(tree, func) {
        var max = 0;
        if (tree && tree.length > 0) {
            var currentDepth = tree[0].depth;
            var fifo = [];
            var currentLevel = [];

            fifo.push(tree[0]);
            while (fifo.length > 0) {
                var node = fifo.shift();
                if (node.depth > currentDepth) {
                    func(currentLevel);
                    currentDepth++;
                    max = Math.max(max, currentLevel.length);
                    currentLevel = [];
                }
                currentLevel.push(node);
                if (node.children) {
                    for (var j = 0; j < node.children.length; j++) {
                        fifo.push(node.children[j]);
                    }
                }
            }
            func(currentLevel);
            return Math.max(max, currentLevel.length);
        }
        return 0;
    }

    function collision(siblings) {
        var minPadding = 5;
        if (siblings) {
            for (var i = 0; i < siblings.length - 1; i++) {
                if (siblings[i + 1].x - (siblings[i].x + boxNode.height) < minPadding)
                    siblings[i + 1].x = siblings[i].x + boxNode.height + minPadding;
            }
        }
    }

    function diagonalArrows(d) {
        var p0 = {
            x: d.source.x + boxNode.height / 2,
            y: (d.source.y + boxNode.width)
        }, p3 = {
            x: d.target.x + boxNode.height / 2,
            y: d.target.y - 12
        }, m = (p0.y + p3.y) / 2, p = [p0, {
            x: p0.x,
            y: m
        }, {
            x: p3.x,
            y: m
        },                 p3];